import javax.microedition.lcdui.*;
import javax.microedition.lcdui.game.*;

public class ExampleGameCanvas extends GameCanvas implements Runnable {
	private boolean isPlay; // Game Loop runs when isPlay is true
	private long delay; // To give thread consistency
	private int currentX, currentY; // To hold current position of the 'X'
	private int width; // To hold screen width
	private int height; // To hold screen height

	// Layers to be used
	private Sprite playerSprite;	
	private TiledLayer backTl;
	
	// Layer Manager
	private LayerManager layerManager;

	// Constructor and initialization
	public ExampleGameCanvas() throws Exception {
		super(true);
		width = getWidth();
		height = getHeight();
		currentX = width / 2;
		currentY = height / 2;
		delay = 20;

		// Load Images to Layers
		Image playerImage = Image.createImage("/sprites.png");
		playerSprite = new Sprite(playerImage, 32, 32);
		
		Image fondo = Image.createImage("/background_tiles.png");
		backTl = new TiledLayer(3, 4, fondo, 75, 75);
		backTl.fillCells(0,0,3,1,1);
		backTl.fillCells(0,3,3,1,5);
		backTl.setCell(0,1,2);
		backTl.setCell(1,1,3);
		backTl.setCell(2,1,4);
		backTl.setCell(0,2,6);
		backTl.setCell(1,2,7);
		backTl.setCell(2,2,8);
		layerManager = new LayerManager();
		layerManager.append(playerSprite);
		layerManager.append(backTl);
		
	}

	// Automatically start thread for game loop
	public void inicio() {
		isPlay = true;
		Thread t = new Thread(this);
		t.start();
	}

	public void stop() {
		isPlay = false;
	}

	// Main Game Loop
	public void run() {
		Graphics g = getGraphics();
		while (isPlay)	{
			input();
			drawScreen(g);
			try	{
				Thread.sleep(delay);
			} catch (InterruptedException ie)	{	}
		}
	}

	// Method to Handle User Inputs
	private void input() {
		int keyStates = getKeyStates();

		playerSprite.setFrame(0);

		// Left
		if ((keyStates & LEFT_PRESSED) != 0){
			currentX = Math.max(0, currentX - 1);
			playerSprite.setFrame(1);
		}

		// Right
		if ((keyStates & RIGHT_PRESSED) != 0)
			if (currentX + 40 < width) {
			    System.out.println("x = " + currentX);
				currentX = Math.min(width, currentX + 1);
				playerSprite.setFrame(3);
			}

		// Up
		if ((keyStates & UP_PRESSED) != 0)	{
			currentY = Math.max(0, currentY - 1);
			playerSprite.setFrame(2);
		}

		// Down
		if ((keyStates & DOWN_PRESSED) != 0)
			if (currentY + 32 < height)	{
				currentY = Math.min(height, currentY + 1);
				playerSprite.setFrame(4);
			}
	}

	// Method to Display Graphics
	private void drawScreen(Graphics g) {
		g.setColor(0xffffffff);
		g.fillRect(0, 0, width, height);

		// updating player sprite position
		playerSprite.setPosition(currentX, currentY);

		layerManager.setViewWindow(0, 0, width-15, height);
		layerManager.paint(g, 7, 0);

		flushGraphics();
	}

} 